import processing.core.*; 
import processing.xml.*; 

import processing.serial.*; 

import java.applet.*; 
import java.awt.Dimension; 
import java.awt.Frame; 
import java.awt.event.MouseEvent; 
import java.awt.event.KeyEvent; 
import java.awt.event.FocusEvent; 
import java.awt.Image; 
import java.io.*; 
import java.net.*; 
import java.text.*; 
import java.util.*; 
import java.util.zip.*; 
import java.util.regex.*; 

public class TempDataLogger extends PApplet {

/*
 Project:    Temperature datalogger
 Description: Receives temperature bytes from USB-UART port and displays the
              temperature on a graphics window. It also provides Start/Stop button 
              for logging the temperature samples.
 Written by:  Rajendra Bhatt (www.embedded-lab.com)
 Date:        2011/10/12     

*/

//import Serial communication library


// Variable declaration
PFont font22, font44;
PFont font12;
float tempC;
float tempF;
float y, h, MS_Byte, LS_Byte;
Serial Dev_Board;
PrintWriter output;
int[] PC_Time = new int[3];
int[] MM_DD_YY = new int[3];
int i, j, xx=-15;
String curr_time, X_Time, curr_date, row_data, filename;

// Button
int rectX, rectY;      // Position of square button
int rectSize = 90;     // Diameter of rect
int rectColor, baseColor;
int rectHighlight;
int currentColor;
boolean rectOver = false, data_logg = false ;


public void setup() {

// Define size of window
size(350, 350);

  //setup fonts for use throughout the application
  font22 = loadFont("MicrosoftYaHei-22.vlw");
  font12 = loadFont("MicrosoftYaHei-12.vlw");  
  font44 = loadFont("FranklinGothic-Demi-32.vlw");
 
  //init serial communication port
  Dev_Board = new Serial(this, "COM6", 9600);
  
  smooth();
  rectColor = color(20);
  rectHighlight = color(80);
  rectX = 220;
  rectY = 200;
  ellipseMode(CENTER);
  
}

public void draw() {
 
 while (Dev_Board.available() > 0)
 {
 MS_Byte = Dev_Board.read();
 delay(100);
 LS_Byte = Dev_Board.read();
 
 background(250, 250, 250); // Light blue color
 fill(200, 6, 0);
 smooth();
 stroke(0);
 strokeWeight(2);
 ellipse(100, 280, 58, 50);
 noStroke();
 fill(0, 46, 200);
 arc(100, 60, 30, 20, PI, PI+PI);
 rect(85,60,30,200);
 // Capillary
 fill(250,250, 250);
 //stroke(0);
 rect(95,60,10,200);

 // Marks on thermometer
 stroke(0);
 strokeWeight(1);
 textAlign(RIGHT);
 fill(0,46,250);
 for (int i = 0; i < 5; i += 1) {
  line(70, 230-40*i, 80, 230-40*i);
  if(i < 4) line(75, 210-40*i, 80, 210-40*i);
  textFont(font12); 
  text(str(40+20*i), 65, 235-40*i); 
 }

 // Centigrade
 textAlign(LEFT);
 for (int i = 0; i < 6; i += 1) {
  line(118, 242-35*i, 128, 242-35*i);
  if(i < 5) line(118, 225-35*i, 123, 225-35*i);
  textFont(font12); 
  text(str(0+10*i), 135, 247-35*i);
 }

 noStroke();
 // text font
 fill(0,46,250);

 textFont(font22); 
 textAlign(LEFT);
 //text("Digital Thermometer", 120, 25); 
 text("F", 57, 46);
 text("C", 135, 46);
 textFont(font12);
 text("o", 45, 35);
 text("o", 125, 35);

 fill(250,90,0);
 textFont(font22);
 text("o", 300+xx, 45);
 text("o", 300+xx, 85);

// LM34DZ
//tempF = MS_Byte*256 + LS_Byte;
//tempF = tempF/5;
//tempC = (tempF - 32)*5/9;

// MCP9701A
tempC = MS_Byte*256 + LS_Byte;
tempC = (2*tempC - 400)/19.5f;
tempF = ((tempC*9)/5) + 32; textFont(font44); 
 text(nfc(tempC, 2), 200+xx, 60);
 text(nfc(tempF, 2), 200+xx, 100);
 text("C", 320+xx, 60);
 text("F", 320+xx, 100);

 // Raise mercury level
 fill(200,0, 0);
 y = -2.0f*tempF + 310;
 h = 270-y;
 rect(95, y, 10, h);

 curr_time = PC_Time();
 curr_date = PC_Date();
 println(curr_date);
 // write data to a file
 open("DataLogger.txt");
 if (data_logg){
 row_data = curr_date + "  "+ curr_time + "  " + nfc(tempC, 2) + "  " + nfc(tempF, 2);
 println(row_data); 
 output.println(row_data); 
 }
}  

update(mouseX, mouseY);
  if(rectOver) {
    fill(rectHighlight);
  } else {
    fill(rectColor);
  }
  stroke(255);
  rect(rectX, rectY, rectSize, rectSize-45);
  textFont(font12);
  textSize(14);
  if(data_logg){
   fill(50,255,52);
   text("Stop Log", rectX+15, rectY+25);
  }
  if(!data_logg){
  fill(50,255,52);
  text("Start Log", rectX+15, rectY+25);
  }
 
}

public void update(int x, int y)
{
  if ( overRect(rectX, rectY, rectSize, rectSize-45) ) {
    rectOver = true;
    } else {
    rectOver = false;
  }
}

public void mousePressed()
{
  if(rectOver) {
    if(data_logg){
     data_logg = false;
     output.flush(); // Write the remaining data
     output.close(); // Finish the file

  } else {
    data_logg = true;
   // Create a new file in the sketch directory
   curr_date = PC_Date();
   curr_time = PC_Time();
   String[] temp = split(curr_date, "  ");
   filename = "DataLogger_"+join(temp, "");
   temp = split(curr_time, "  ");
   filename = filename+join(temp, "")+".txt";
   output = createWriter(filename);
   output.println("MM  DD  YYYY  HH  MM  SS    C     F");
      
  }
  }
}

public boolean overRect(int x, int y, int width, int height) 
{
  if (mouseX >= x && mouseX <= x+width && 
      mouseY >= y && mouseY <= y+height) {
    return true;
  } else {
    return false;
  }
}

public String PC_Time()
{
  
 PC_Time[2] = second();  // Values from 0 - 59
 PC_Time[1] = minute();  // Values from 0 - 59
 PC_Time[0] = hour();    // Values from 0 - 23
 return join(nf(PC_Time, 2), "  ");

}

public String PC_Date()
{
  
 MM_DD_YY[2] = year();  
 MM_DD_YY[1] = day();  
 MM_DD_YY[0] = month();   
 return join(nf(MM_DD_YY, 2), "  ");
}


  static public void main(String args[]) {
    PApplet.main(new String[] { "--bgcolor=#F0F0F0", "TempDataLogger" });
  }
}
